@@ -35,6 +35,7 @@ struct _GepubWidget {
     gint init_chapter_pos;
     gint margin; // lateral margin in px
     gint font_size; // font size in pt
+    gchar *font_family;
     gfloat line_height;
 };
 
@@ -163,17 +164,18 @@ reload_length_cb (GtkWidget *widget,
 {
     GepubWidget *gwidget = GEPUB_WIDGET (widget);
     WebKitWebView *web_view = WEBKIT_WEB_VIEW (widget);
-    int m, f;
-    float l;
-    char *script;
+    int margin, font_size;
+    float line_height;
+    gchar *script, *font_family;
 
     webkit_web_view_run_javascript (web_view,
         "window.innerWidth",
         NULL, get_length_finished, (gpointer)widget);
 
-    m = GEPUB_WIDGET (widget)->margin;
-    f = GEPUB_WIDGET (widget)->font_size;
-    l = GEPUB_WIDGET (widget)->line_height;
+    margin = gwidget->margin;
+    font_size = gwidget->font_size;
+    font_family = gwidget->font_family;
+    line_height = gwidget->line_height;
 
     script = g_strdup_printf (
         "if (!document.querySelector('#gepubwrap'))"
@@ -181,28 +183,36 @@ reload_length_cb (GtkWidget *widget,
 
         "document.querySelector('#gepubwrap').style.marginLeft = '%dpx';"
         "document.querySelector('#gepubwrap').style.marginRight = '%dpx';"
-        , m, m);
+        , margin, margin);
     webkit_web_view_run_javascript (web_view, script, NULL, NULL, NULL);
     g_free (script);
 
-    if (f) {
+    if (font_size) {
         script = g_strdup_printf (
             "document.querySelector('#gepubwrap').style.fontSize = '%dpt';"
-            , f);
+            , font_size);
         webkit_web_view_run_javascript (web_view, script, NULL, NULL, NULL);
         g_free (script);
     }
 
-    if (l) {
-        char line_height[G_ASCII_DTOSTR_BUF_SIZE];
+    if (font_family) {
+        script = g_strdup_printf (
+            "document.querySelector('#gepubwrap').style.fontFamily = '%s';"
+            , font_family);
+        webkit_web_view_run_javascript (web_view, script, NULL, NULL, NULL);
+        g_free (script);
+    }
 
-        g_ascii_formatd (line_height,
+    if (line_height) {
+        gchar line_height_buffer[G_ASCII_DTOSTR_BUF_SIZE];
+
+        g_ascii_formatd (line_height_buffer,
                          G_ASCII_DTOSTR_BUF_SIZE,
                          "%f",
-                         l);
+                         line_height);
         script = g_strdup_printf (
             "document.querySelector('#gepubwrap').style.lineHeight = %s;"
-            , line_height);
+            , line_height_buffer);
         webkit_web_view_run_javascript (web_view, script, NULL, NULL, NULL);
         g_free (script);
     }
@@ -251,9 +261,16 @@ resource_callback (WebKitURISchemeRequest *request, gpointer user_data)
     contents = gepub_doc_get_resource (widget->doc, path);
     mime = gepub_doc_get_resource_mime (widget->doc, path);
 
+    // if the resource requested doesn't exist, we should serve an
+    // empty document instead of nothing at all (otherwise some
+    // poorly-structured ebooks will fail to render).
+    if (!contents) {
+        contents = g_byte_array_free_to_bytes(g_byte_array_sized_new(0));
+        mime = g_strdup("application/octet-stream");
+    }
+
     if (!mime) {
-        g_free (uri);
-        return;
+        mime = g_strdup("application/octet-stream");
     }
 
     stream = g_memory_input_stream_new_from_bytes (contents);
@@ -281,7 +298,7 @@ gepub_widget_set_property (GObject      *object,
         gepub_widget_set_paginate (widget, g_value_get_boolean (value));
         break;
     case PROP_CHAPTER:
-        gepub_doc_set_page (widget->doc, g_value_get_int (value));
+        gepub_doc_set_chapter (widget->doc, g_value_get_int (value));
         break;
     case PROP_CHAPTER_POS:
         gepub_widget_set_pos (widget, g_value_get_float (value));
@@ -308,10 +325,10 @@ gepub_widget_get_property (GObject    *object,
         g_value_set_boolean (value, widget->paginate);
         break;
     case PROP_CHAPTER:
-        g_value_set_int (value, gepub_doc_get_page (widget->doc));
+        g_value_set_int (value, gepub_doc_get_chapter (widget->doc));
         break;
     case PROP_N_CHAPTERS:
-        g_value_set_int (value, gepub_doc_get_n_pages (widget->doc));
+        g_value_set_int (value, gepub_doc_get_n_chapters (widget->doc));
         break;
     case PROP_CHAPTER_POS:
         g_value_set_float (value, gepub_widget_get_pos (widget));
@@ -327,6 +344,7 @@ gepub_widget_finalize (GObject *object)
 {
     GepubWidget *widget = GEPUB_WIDGET (object);
 
+    g_clear_pointer (&widget->font_family, g_free);
     g_clear_object (&widget->doc);
 
     G_OBJECT_CLASS (gepub_widget_parent_class)->finalize (object);
@@ -342,6 +360,7 @@ gepub_widget_init (GepubWidget *widget)
     widget->init_chapter_pos = 0;
     widget->margin = 20;
     widget->font_size = 0;
+    widget->font_family = NULL;
     widget->line_height = 0;
 }
 
@@ -443,6 +462,9 @@ reload_current_chapter (GepubWidget *widget)
     widget->chapter_pos = 0;
     widget->length = 0;
 
+    if (widget->doc == NULL)
+        return;
+
     current = gepub_doc_get_current_with_epub_uris (widget->doc);
     webkit_web_view_load_bytes (WEBKIT_WEB_VIEW (widget),
                                 current,
@@ -478,7 +500,7 @@ gepub_widget_set_doc (GepubWidget *widget,
     if (widget->doc != NULL) {
         g_object_ref (widget->doc);
         reload_current_chapter (widget);
-        g_signal_connect_swapped (widget->doc, "notify::page",
+        g_signal_connect_swapped (widget->doc, "notify::chapter",
                                   G_CALLBACK (reload_current_chapter), widget);
     }
 
@@ -526,7 +548,7 @@ gint
 gepub_widget_get_n_chapters (GepubWidget *widget)
 {
     g_return_val_if_fail (GEPUB_IS_DOC (widget->doc), 0);
-    return gepub_doc_get_n_pages (widget->doc);
+    return gepub_doc_get_n_chapters (widget->doc);
 }
 
 /**
@@ -539,7 +561,7 @@ gint
 gepub_widget_get_chapter (GepubWidget *widget)
 {
     g_return_val_if_fail (GEPUB_IS_DOC (widget->doc), 0);
-    return gepub_doc_get_page (widget->doc);
+    return gepub_doc_get_chapter (widget->doc);
 }
 
 /**
@@ -567,7 +589,7 @@ gepub_widget_set_chapter (GepubWidget *widget,
                           gint         index)
 {
     g_return_if_fail (GEPUB_IS_DOC (widget->doc));
-    return gepub_doc_set_page (widget->doc, index);
+    return gepub_doc_set_chapter (widget->doc, index);
 }
 
 /**
@@ -733,6 +755,35 @@ gepub_widget_set_fontsize (GepubWidget *widget,
     reload_length_cb (GTK_WIDGET (widget), NULL, NULL);
 }
 
+/**
+ * gepub_widget_get_fontfamily:
+ * @widget: a #GepubWidget
+ *
+ * Gets the widget custom font family
+ */
+gchar *
+gepub_widget_get_fontfamily (GepubWidget *widget)
+{
+    return widget->font_family;
+}
+
+/**
+ * gepub_widget_set_fontfamily:
+ * @widget: a #GepubWidget
+ * @family: the custom font family name
+ *
+ * Sets the widget custom font family
+ */
+void
+gepub_widget_set_fontfamily (GepubWidget *widget,
+                             gchar       *family)
+{
+    g_clear_pointer (&widget->font_family, g_free);
+
+    widget->font_family = g_strdup (family);
+    reload_length_cb (GTK_WIDGET (widget), NULL, NULL);
+}
+
 /**
  * gepub_widget_get_lineheight:
  * @widget: a #GepubWidget
